This function implements one step of the sequential importance sampling method for a target with passive sonar.
Sstep.Sonar(mm, xx, logww, yy, par, xdim = 1, ydim = 1)the Monte Carlo sample size m.
the sample in the last iteration.
the log weight in the last iteration.
the observations with T columns and ydim rows.
a list of parameter values. H is the state coefficient matrix, W*t(W) is the state innovation covariance matrix,
V*t(V) is the covariance matrix of the observation noise, s2 is the second sonar location.
the dimension of the state variable x_t.
the dimension of the observation y_t.
The function returns a list with the following components:
the new sample.
the log weights.
Tsay, R. and Chen, R. (2018). Nonlinear Time Series Analysis. John Wiley & Sons, New Jersey.